# EduNLP

[![PyPI](https://img.shields.io/pypi/v/EduNLP.svg)](https://pypi.python.org/pypi/EduNLP)
[![Build Status](https://www.travis-ci.org/bigdata-ustc/EduNLP.svg?branch=master)](https://www.travis-ci.org/bigdata-ustc/EduNLP)
[![codecov](https://codecov.io/gh/bigdata-ustc/EduNLP/branch/master/graph/badge.svg?token=B7gscOGQLD)](https://codecov.io/gh/bigdata-ustc/EduNLP)
[![Download](https://img.shields.io/pypi/dm/EduNLP.svg?style=flat)](https://pypi.python.org/pypi/EduNLP)
[![License](https://img.shields.io/github/license/bigdata-ustc/EduNLP)](LICENSE)

NLP tools for Educational data (e.g., exercise, papers)
